Code
Hub
Workspaces
Following
Trending
Connect
MCP
copy
Create free account
hub
/
github.com/ROCm/rocPRIM
/ lane_id_kernel
Function
lane_id_kernel
test/rocprim/test_intrinsics.cpp:492–497 ·
view source on GitHub ↗
Source
from the content-addressed store, hash-verified
490
}
491
492
__global__
493
void lane_id_kernel(unsigned int* data)
494
{
495
const unsigned int index = blockIdx.x * blockDim.x + threadIdx.x;
496
data[index] = rocprim::lane_id();
497
}
498
499
TEST(RocprimIntrinsicsTests, LaneId)
500
{
Callers
nothing calls this directly
Calls
1
lane_id
Function · 0.85
Tested by
no test coverage detected